@@ -18,15 +18,14 @@
 #include "kmime_warning.h"
 
 #include <config-kmime.h>
-// #include <kdefakes.h> // for strcasestr
 
 #include <KCharsets>
 #include <QCoreApplication>
+#include <QRegularExpression>
 
-
-#include <ctype.h>
-#include <time.h>
-#include <stdlib.h>
+#include <cctype>
+#include <cstdlib>
+#include <ctime>
 
 using namespace KMime;
 
@@ -184,7 +183,7 @@ QByteArray unfoldHeader(const char *header, size_t headerSize)
     while ((foldMid = strchr(pos, '\n')) && foldMid < end) {
         foldBegin = foldEnd = foldMid;
         // find the first space before the line-break
-        while (foldBegin) {
+        while (foldBegin > header) {
             if (!QChar::isSpace(*(foldBegin - 1))) {
                 break;
             }
@@ -208,7 +207,7 @@ QByteArray unfoldHeader(const char *header, size_t headerSize)
         }
 
         result.append(pos, foldBegin - pos);
-        if (foldEnd < end - 1) {
+        if (foldBegin != pos && foldEnd < end - 1) {
             result += ' ';
         }
         pos = foldEnd;
@@ -281,7 +280,7 @@ int findHeaderLineEnd(const QByteArray &src, int &dataBegin, bool *folded)
     return end;
 }
 
-#ifndef HAVE_STRCASESTR
+#if !HAVE_STRCASESTR
 #ifdef WIN32
 #define strncasecmp _strnicmp
 #endif
@@ -457,7 +456,7 @@ void addQuotes_impl(StringType &str, bool forceQuotes)
     bool needsQuotes = false;
     for (int i = 0; i < str.length(); i++) {
         const CharType cur = str.at(i);
-        if (QString(ToString(str)).contains(QRegExp(QStringLiteral("\"|\\\\|=|\\]|\\[|:|;|,|\\.|,|@|<|>|\\)|\\(")))) {
+        if (QString(ToString(str)).contains(QRegularExpression(QStringLiteral("\"|\\\\|=|\\]|\\[|:|;|,|\\.|,|@|<|>|\\)|\\(")))) {
             needsQuotes = true;
         }
         if (cur == CharConverterType('\\') || cur == CharConverterType('\"')) {
@@ -535,10 +534,10 @@ QString removeBidiControlChars(const QString &input)
     const int LRE = 0x202A;
     const int RLE = 0x202B;
     QString result = input;
-    result.remove(LRO);
-    result.remove(RLO);
-    result.remove(LRE);
-    result.remove(RLE);
+    result.remove(QChar(LRO));
+    result.remove(QChar(RLO));
+    result.remove(QChar(LRE));
+    result.remove(QChar(RLE));
     return result;
 }
 
